import { ClientOptions } from "../../client";
import { CustomerOptions } from "../../types";
import { Service } from "../../service";
import { resources, services, protobuf, longrunning } from "../index";
import { Hooks } from "../../hooks";
export default class ServiceFactory extends Service {
    constructor(clientOptions: ClientOptions, customerOptions: CustomerOptions, hooks?: Hooks);
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/AccountBudgetProposalService
     */
    get accountBudgetProposals(): {
        /**
         * @description create resources of type resources.IAccountBudgetProposal
         * @returns services.MutateAccountBudgetProposalResponse
         */
        create: (accountBudgetProposals: (resources.IAccountBudgetProposal | resources.AccountBudgetProposal)[], options?: Partial<Pick<services.IMutateAccountBudgetProposalRequest, "validate_only">>) => Promise<services.MutateAccountBudgetProposalResponse>;
        /**
         * @description remove resources of type string
         * @returns services.MutateAccountBudgetProposalResponse
         */
        remove: (accountBudgetProposals: string[], options?: Partial<Pick<services.IMutateAccountBudgetProposalRequest, "validate_only">>) => Promise<services.MutateAccountBudgetProposalResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/AccountLinkService
     */
    get accountLinks(): {
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/AccountLinkService#createaccountlink
         */
        createAccountLink: (request: services.CreateAccountLinkRequest) => Promise<services.CreateAccountLinkResponse>;
        /**
         * @description update resources of type resources.IAccountLink
         * @returns services.MutateAccountLinkResponse
         */
        update: (accountLinks: (resources.IAccountLink | resources.AccountLink)[], options?: Partial<Pick<services.IMutateAccountLinkRequest, "validate_only" | "partial_failure">>) => Promise<services.MutateAccountLinkResponse>;
        /**
         * @description remove resources of type string
         * @returns services.MutateAccountLinkResponse
         */
        remove: (accountLinks: string[], options?: Partial<Pick<services.IMutateAccountLinkRequest, "validate_only" | "partial_failure">>) => Promise<services.MutateAccountLinkResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/AdGroupAdLabelService
     */
    get adGroupAdLabels(): {
        /**
         * @description create resources of type resources.IAdGroupAdLabel
         * @returns services.MutateAdGroupAdLabelsResponse
         */
        create: (adGroupAdLabels: (resources.IAdGroupAdLabel | resources.AdGroupAdLabel)[], options?: Partial<Pick<services.IMutateAdGroupAdLabelsRequest, "validate_only" | "partial_failure">>) => Promise<services.MutateAdGroupAdLabelsResponse>;
        /**
         * @description remove resources of type string
         * @returns services.MutateAdGroupAdLabelsResponse
         */
        remove: (adGroupAdLabels: string[], options?: Partial<Pick<services.IMutateAdGroupAdLabelsRequest, "validate_only" | "partial_failure">>) => Promise<services.MutateAdGroupAdLabelsResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/AdGroupAdService
     */
    get adGroupAds(): {
        /**
         * @description create resources of type resources.IAdGroupAd
         * @returns services.MutateAdGroupAdsResponse
         */
        create: (adGroupAds: (resources.IAdGroupAd | resources.AdGroupAd)[], options?: Partial<Pick<services.IMutateAdGroupAdsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateAdGroupAdsResponse>;
        /**
         * @description update resources of type resources.IAdGroupAd
         * @returns services.MutateAdGroupAdsResponse
         */
        update: (adGroupAds: (resources.IAdGroupAd | resources.AdGroupAd)[], options?: Partial<Pick<services.IMutateAdGroupAdsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateAdGroupAdsResponse>;
        /**
         * @description remove resources of type string
         * @returns services.MutateAdGroupAdsResponse
         */
        remove: (adGroupAds: string[], options?: Partial<Pick<services.IMutateAdGroupAdsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateAdGroupAdsResponse>;
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/AdGroupAdService#removeautomaticallycreatedassets
         */
        removeAutomaticallyCreatedAssets: (request: services.RemoveAutomaticallyCreatedAssetsRequest) => Promise<protobuf.Empty>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/AdGroupAssetService
     */
    get adGroupAssets(): {
        /**
         * @description create resources of type resources.IAdGroupAsset
         * @returns services.MutateAdGroupAssetsResponse
         */
        create: (adGroupAssets: (resources.IAdGroupAsset | resources.AdGroupAsset)[], options?: Partial<Pick<services.IMutateAdGroupAssetsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateAdGroupAssetsResponse>;
        /**
         * @description update resources of type resources.IAdGroupAsset
         * @returns services.MutateAdGroupAssetsResponse
         */
        update: (adGroupAssets: (resources.IAdGroupAsset | resources.AdGroupAsset)[], options?: Partial<Pick<services.IMutateAdGroupAssetsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateAdGroupAssetsResponse>;
        /**
         * @description remove resources of type string
         * @returns services.MutateAdGroupAssetsResponse
         */
        remove: (adGroupAssets: string[], options?: Partial<Pick<services.IMutateAdGroupAssetsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateAdGroupAssetsResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/AdGroupAssetSetService
     */
    get adGroupAssetSets(): {
        /**
         * @description create resources of type resources.IAdGroupAssetSet
         * @returns services.MutateAdGroupAssetSetsResponse
         */
        create: (adGroupAssetSets: (resources.IAdGroupAssetSet | resources.AdGroupAssetSet)[], options?: Partial<Pick<services.IMutateAdGroupAssetSetsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateAdGroupAssetSetsResponse>;
        /**
         * @description remove resources of type string
         * @returns services.MutateAdGroupAssetSetsResponse
         */
        remove: (adGroupAssetSets: string[], options?: Partial<Pick<services.IMutateAdGroupAssetSetsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateAdGroupAssetSetsResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/AdGroupBidModifierService
     */
    get adGroupBidModifiers(): {
        /**
         * @description create resources of type resources.IAdGroupBidModifier
         * @returns services.MutateAdGroupBidModifiersResponse
         */
        create: (adGroupBidModifiers: (resources.IAdGroupBidModifier | resources.AdGroupBidModifier)[], options?: Partial<Pick<services.IMutateAdGroupBidModifiersRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateAdGroupBidModifiersResponse>;
        /**
         * @description update resources of type resources.IAdGroupBidModifier
         * @returns services.MutateAdGroupBidModifiersResponse
         */
        update: (adGroupBidModifiers: (resources.IAdGroupBidModifier | resources.AdGroupBidModifier)[], options?: Partial<Pick<services.IMutateAdGroupBidModifiersRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateAdGroupBidModifiersResponse>;
        /**
         * @description remove resources of type string
         * @returns services.MutateAdGroupBidModifiersResponse
         */
        remove: (adGroupBidModifiers: string[], options?: Partial<Pick<services.IMutateAdGroupBidModifiersRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateAdGroupBidModifiersResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/AdGroupCriterionCustomizerService
     */
    get adGroupCriterionCustomizers(): {
        /**
         * @description create resources of type resources.IAdGroupCriterionCustomizer
         * @returns services.MutateAdGroupCriterionCustomizersResponse
         */
        create: (adGroupCriterionCustomizers: (resources.IAdGroupCriterionCustomizer | resources.AdGroupCriterionCustomizer)[], options?: Partial<Pick<services.IMutateAdGroupCriterionCustomizersRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateAdGroupCriterionCustomizersResponse>;
        /**
         * @description remove resources of type string
         * @returns services.MutateAdGroupCriterionCustomizersResponse
         */
        remove: (adGroupCriterionCustomizers: string[], options?: Partial<Pick<services.IMutateAdGroupCriterionCustomizersRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateAdGroupCriterionCustomizersResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/AdGroupCriterionLabelService
     */
    get adGroupCriterionLabels(): {
        /**
         * @description create resources of type resources.IAdGroupCriterionLabel
         * @returns services.MutateAdGroupCriterionLabelsResponse
         */
        create: (adGroupCriterionLabels: (resources.IAdGroupCriterionLabel | resources.AdGroupCriterionLabel)[], options?: Partial<Pick<services.IMutateAdGroupCriterionLabelsRequest, "validate_only" | "partial_failure">>) => Promise<services.MutateAdGroupCriterionLabelsResponse>;
        /**
         * @description remove resources of type string
         * @returns services.MutateAdGroupCriterionLabelsResponse
         */
        remove: (adGroupCriterionLabels: string[], options?: Partial<Pick<services.IMutateAdGroupCriterionLabelsRequest, "validate_only" | "partial_failure">>) => Promise<services.MutateAdGroupCriterionLabelsResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/AdGroupCriterionService
     */
    get adGroupCriteria(): {
        /**
         * @description create resources of type resources.IAdGroupCriterion
         * @returns services.MutateAdGroupCriteriaResponse
         */
        create: (adGroupCriteria: ((resources.IAdGroupCriterion & {
            exempt_policy_violation_keys?: services.AdGroupCriterionOperation["exempt_policy_violation_keys"];
        }) | (resources.AdGroupCriterion & {
            exempt_policy_violation_keys?: services.AdGroupCriterionOperation["exempt_policy_violation_keys"];
        }))[], options?: Partial<Pick<services.IMutateAdGroupCriteriaRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateAdGroupCriteriaResponse>;
        /**
         * @description update resources of type resources.IAdGroupCriterion
         * @returns services.MutateAdGroupCriteriaResponse
         */
        update: (adGroupCriteria: ((resources.IAdGroupCriterion & {
            exempt_policy_violation_keys?: services.AdGroupCriterionOperation["exempt_policy_violation_keys"];
        }) | (resources.AdGroupCriterion & {
            exempt_policy_violation_keys?: services.AdGroupCriterionOperation["exempt_policy_violation_keys"];
        }))[], options?: Partial<Pick<services.IMutateAdGroupCriteriaRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateAdGroupCriteriaResponse>;
        /**
         * @description remove resources of type string
         * @returns services.MutateAdGroupCriteriaResponse
         */
        remove: (adGroupCriteria: string[], options?: Partial<Pick<services.IMutateAdGroupCriteriaRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateAdGroupCriteriaResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/AdGroupCustomizerService
     */
    get adGroupCustomizers(): {
        /**
         * @description create resources of type resources.IAdGroupCustomizer
         * @returns services.MutateAdGroupCustomizersResponse
         */
        create: (adGroupCustomizers: (resources.IAdGroupCustomizer | resources.AdGroupCustomizer)[], options?: Partial<Pick<services.IMutateAdGroupCustomizersRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateAdGroupCustomizersResponse>;
        /**
         * @description remove resources of type string
         * @returns services.MutateAdGroupCustomizersResponse
         */
        remove: (adGroupCustomizers: string[], options?: Partial<Pick<services.IMutateAdGroupCustomizersRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateAdGroupCustomizersResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/AdGroupLabelService
     */
    get adGroupLabels(): {
        /**
         * @description create resources of type resources.IAdGroupLabel
         * @returns services.MutateAdGroupLabelsResponse
         */
        create: (adGroupLabels: (resources.IAdGroupLabel | resources.AdGroupLabel)[], options?: Partial<Pick<services.IMutateAdGroupLabelsRequest, "validate_only" | "partial_failure">>) => Promise<services.MutateAdGroupLabelsResponse>;
        /**
         * @description remove resources of type string
         * @returns services.MutateAdGroupLabelsResponse
         */
        remove: (adGroupLabels: string[], options?: Partial<Pick<services.IMutateAdGroupLabelsRequest, "validate_only" | "partial_failure">>) => Promise<services.MutateAdGroupLabelsResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/AdGroupService
     */
    get adGroups(): {
        /**
         * @description create resources of type resources.IAdGroup
         * @returns services.MutateAdGroupsResponse
         */
        create: (adGroups: (resources.IAdGroup | resources.AdGroup)[], options?: Partial<Pick<services.IMutateAdGroupsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateAdGroupsResponse>;
        /**
         * @description update resources of type resources.IAdGroup
         * @returns services.MutateAdGroupsResponse
         */
        update: (adGroups: (resources.IAdGroup | resources.AdGroup)[], options?: Partial<Pick<services.IMutateAdGroupsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateAdGroupsResponse>;
        /**
         * @description remove resources of type string
         * @returns services.MutateAdGroupsResponse
         */
        remove: (adGroups: string[], options?: Partial<Pick<services.IMutateAdGroupsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateAdGroupsResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/AdParameterService
     */
    get adParameters(): {
        /**
         * @description create resources of type resources.IAdParameter
         * @returns services.MutateAdParametersResponse
         */
        create: (adParameters: (resources.IAdParameter | resources.AdParameter)[], options?: Partial<Pick<services.IMutateAdParametersRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateAdParametersResponse>;
        /**
         * @description update resources of type resources.IAdParameter
         * @returns services.MutateAdParametersResponse
         */
        update: (adParameters: (resources.IAdParameter | resources.AdParameter)[], options?: Partial<Pick<services.IMutateAdParametersRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateAdParametersResponse>;
        /**
         * @description remove resources of type string
         * @returns services.MutateAdParametersResponse
         */
        remove: (adParameters: string[], options?: Partial<Pick<services.IMutateAdParametersRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateAdParametersResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/AdService
     */
    get ads(): {
        /**
         * @description update resources of type resources.IAd
         * @returns services.MutateAdsResponse
         */
        update: (ads: (resources.IAd | resources.Ad)[], options?: Partial<Pick<services.IMutateAdsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateAdsResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/AssetGroupAssetService
     */
    get assetGroupAssets(): {
        /**
         * @description create resources of type resources.IAssetGroupAsset
         * @returns services.MutateAssetGroupAssetsResponse
         */
        create: (assetGroupAssets: (resources.IAssetGroupAsset | resources.AssetGroupAsset)[], options?: Partial<Pick<services.IMutateAssetGroupAssetsRequest, "validate_only" | "partial_failure">>) => Promise<services.MutateAssetGroupAssetsResponse>;
        /**
         * @description update resources of type resources.IAssetGroupAsset
         * @returns services.MutateAssetGroupAssetsResponse
         */
        update: (assetGroupAssets: (resources.IAssetGroupAsset | resources.AssetGroupAsset)[], options?: Partial<Pick<services.IMutateAssetGroupAssetsRequest, "validate_only" | "partial_failure">>) => Promise<services.MutateAssetGroupAssetsResponse>;
        /**
         * @description remove resources of type string
         * @returns services.MutateAssetGroupAssetsResponse
         */
        remove: (assetGroupAssets: string[], options?: Partial<Pick<services.IMutateAssetGroupAssetsRequest, "validate_only" | "partial_failure">>) => Promise<services.MutateAssetGroupAssetsResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/AssetGroupListingGroupFilterService
     */
    get assetGroupListingGroupFilters(): {
        /**
         * @description create resources of type resources.IAssetGroupListingGroupFilter
         * @returns services.MutateAssetGroupListingGroupFiltersResponse
         */
        create: (assetGroupListingGroupFilters: (resources.IAssetGroupListingGroupFilter | resources.AssetGroupListingGroupFilter)[], options?: Partial<Pick<services.IMutateAssetGroupListingGroupFiltersRequest, "validate_only" | "response_content_type">>) => Promise<services.MutateAssetGroupListingGroupFiltersResponse>;
        /**
         * @description update resources of type resources.IAssetGroupListingGroupFilter
         * @returns services.MutateAssetGroupListingGroupFiltersResponse
         */
        update: (assetGroupListingGroupFilters: (resources.IAssetGroupListingGroupFilter | resources.AssetGroupListingGroupFilter)[], options?: Partial<Pick<services.IMutateAssetGroupListingGroupFiltersRequest, "validate_only" | "response_content_type">>) => Promise<services.MutateAssetGroupListingGroupFiltersResponse>;
        /**
         * @description remove resources of type string
         * @returns services.MutateAssetGroupListingGroupFiltersResponse
         */
        remove: (assetGroupListingGroupFilters: string[], options?: Partial<Pick<services.IMutateAssetGroupListingGroupFiltersRequest, "validate_only" | "response_content_type">>) => Promise<services.MutateAssetGroupListingGroupFiltersResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/AssetGroupService
     */
    get assetGroups(): {
        /**
         * @description create resources of type resources.IAssetGroup
         * @returns services.MutateAssetGroupsResponse
         */
        create: (assetGroups: (resources.IAssetGroup | resources.AssetGroup)[], options?: Partial<Pick<services.IMutateAssetGroupsRequest, "validate_only">>) => Promise<services.MutateAssetGroupsResponse>;
        /**
         * @description update resources of type resources.IAssetGroup
         * @returns services.MutateAssetGroupsResponse
         */
        update: (assetGroups: (resources.IAssetGroup | resources.AssetGroup)[], options?: Partial<Pick<services.IMutateAssetGroupsRequest, "validate_only">>) => Promise<services.MutateAssetGroupsResponse>;
        /**
         * @description remove resources of type string
         * @returns services.MutateAssetGroupsResponse
         */
        remove: (assetGroups: string[], options?: Partial<Pick<services.IMutateAssetGroupsRequest, "validate_only">>) => Promise<services.MutateAssetGroupsResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/AssetGroupSignalService
     */
    get assetGroupSignals(): {
        /**
         * @description create resources of type resources.IAssetGroupSignal
         * @returns services.MutateAssetGroupSignalsResponse
         */
        create: (assetGroupSignals: (resources.IAssetGroupSignal | resources.AssetGroupSignal)[], options?: Partial<Pick<services.IMutateAssetGroupSignalsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateAssetGroupSignalsResponse>;
        /**
         * @description remove resources of type string
         * @returns services.MutateAssetGroupSignalsResponse
         */
        remove: (assetGroupSignals: string[], options?: Partial<Pick<services.IMutateAssetGroupSignalsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateAssetGroupSignalsResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/AssetService
     */
    get assets(): {
        /**
         * @description create resources of type resources.IAsset
         * @returns services.MutateAssetsResponse
         */
        create: (assets: (resources.IAsset | resources.Asset)[], options?: Partial<Pick<services.IMutateAssetsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateAssetsResponse>;
        /**
         * @description update resources of type resources.IAsset
         * @returns services.MutateAssetsResponse
         */
        update: (assets: (resources.IAsset | resources.Asset)[], options?: Partial<Pick<services.IMutateAssetsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateAssetsResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/AssetSetAssetService
     */
    get assetSetAssets(): {
        /**
         * @description create resources of type resources.IAssetSetAsset
         * @returns services.MutateAssetSetAssetsResponse
         */
        create: (assetSetAssets: (resources.IAssetSetAsset | resources.AssetSetAsset)[], options?: Partial<Pick<services.IMutateAssetSetAssetsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateAssetSetAssetsResponse>;
        /**
         * @description remove resources of type string
         * @returns services.MutateAssetSetAssetsResponse
         */
        remove: (assetSetAssets: string[], options?: Partial<Pick<services.IMutateAssetSetAssetsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateAssetSetAssetsResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/AssetSetService
     */
    get assetSets(): {
        /**
         * @description create resources of type resources.IAssetSet
         * @returns services.MutateAssetSetsResponse
         */
        create: (assetSets: (resources.IAssetSet | resources.AssetSet)[], options?: Partial<Pick<services.IMutateAssetSetsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateAssetSetsResponse>;
        /**
         * @description update resources of type resources.IAssetSet
         * @returns services.MutateAssetSetsResponse
         */
        update: (assetSets: (resources.IAssetSet | resources.AssetSet)[], options?: Partial<Pick<services.IMutateAssetSetsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateAssetSetsResponse>;
        /**
         * @description remove resources of type string
         * @returns services.MutateAssetSetsResponse
         */
        remove: (assetSets: string[], options?: Partial<Pick<services.IMutateAssetSetsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateAssetSetsResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/AudienceInsightsService
     */
    get audienceInsights(): {
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/AudienceInsightsService#generateinsightsfinderreport
         */
        generateInsightsFinderReport: (request: services.GenerateInsightsFinderReportRequest) => Promise<services.GenerateInsightsFinderReportResponse>;
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/AudienceInsightsService#listaudienceinsightsattributes
         */
        listAudienceInsightsAttributes: (request: services.ListAudienceInsightsAttributesRequest) => Promise<services.ListAudienceInsightsAttributesResponse>;
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/AudienceInsightsService#listinsightseligibledates
         */
        listInsightsEligibleDates: (request: services.ListInsightsEligibleDatesRequest) => Promise<services.ListInsightsEligibleDatesResponse>;
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/AudienceInsightsService#generateaudiencecompositioninsights
         */
        generateAudienceCompositionInsights: (request: services.GenerateAudienceCompositionInsightsRequest) => Promise<services.GenerateAudienceCompositionInsightsResponse>;
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/AudienceInsightsService#generatesuggestedtargetinginsights
         */
        generateSuggestedTargetingInsights: (request: services.GenerateSuggestedTargetingInsightsRequest) => Promise<services.GenerateSuggestedTargetingInsightsResponse>;
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/AudienceInsightsService#generateaudienceoverlapinsights
         */
        generateAudienceOverlapInsights: (request: services.GenerateAudienceOverlapInsightsRequest) => Promise<services.GenerateAudienceOverlapInsightsResponse>;
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/AudienceInsightsService#generatetargetingsuggestionmetrics
         */
        generateTargetingSuggestionMetrics: (request: services.GenerateTargetingSuggestionMetricsRequest) => Promise<services.GenerateTargetingSuggestionMetricsResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/AudienceService
     */
    get audiences(): {
        /**
         * @description create resources of type resources.IAudience
         * @returns services.MutateAudiencesResponse
         */
        create: (audiences: (resources.IAudience | resources.Audience)[], options?: Partial<Pick<services.IMutateAudiencesRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateAudiencesResponse>;
        /**
         * @description update resources of type resources.IAudience
         * @returns services.MutateAudiencesResponse
         */
        update: (audiences: (resources.IAudience | resources.Audience)[], options?: Partial<Pick<services.IMutateAudiencesRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateAudiencesResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/BatchJobService
     */
    get batchJobs(): {
        /**
         * @description create resources of type resources.IBatchJob
         * @returns services.MutateBatchJobResponse
         */
        create: (batchJobs: (resources.IBatchJob | resources.BatchJob)[], options?: never) => Promise<services.MutateBatchJobResponse>;
        /**
         * @description remove resources of type string
         * @returns services.MutateBatchJobResponse
         */
        remove: (batchJobs: string[], options?: never) => Promise<services.MutateBatchJobResponse>;
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/BatchJobService#listbatchjobresults
         */
        listBatchJobResults: (request: services.ListBatchJobResultsRequest) => Promise<services.ListBatchJobResultsResponse>;
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/BatchJobService#runbatchjob
         */
        runBatchJob: (request: services.RunBatchJobRequest) => Promise<longrunning.Operation>;
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/BatchJobService#addbatchjoboperations
         */
        addBatchJobOperations: (request: services.AddBatchJobOperationsRequest) => Promise<services.AddBatchJobOperationsResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/BiddingDataExclusionService
     */
    get biddingDataExclusions(): {
        /**
         * @description create resources of type resources.IBiddingDataExclusion
         * @returns services.MutateBiddingDataExclusionsResponse
         */
        create: (biddingDataExclusions: (resources.IBiddingDataExclusion | resources.BiddingDataExclusion)[], options?: Partial<Pick<services.IMutateBiddingDataExclusionsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateBiddingDataExclusionsResponse>;
        /**
         * @description update resources of type resources.IBiddingDataExclusion
         * @returns services.MutateBiddingDataExclusionsResponse
         */
        update: (biddingDataExclusions: (resources.IBiddingDataExclusion | resources.BiddingDataExclusion)[], options?: Partial<Pick<services.IMutateBiddingDataExclusionsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateBiddingDataExclusionsResponse>;
        /**
         * @description remove resources of type string
         * @returns services.MutateBiddingDataExclusionsResponse
         */
        remove: (biddingDataExclusions: string[], options?: Partial<Pick<services.IMutateBiddingDataExclusionsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateBiddingDataExclusionsResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/BiddingSeasonalityAdjustmentService
     */
    get biddingSeasonalityAdjustments(): {
        /**
         * @description create resources of type resources.IBiddingSeasonalityAdjustment
         * @returns services.MutateBiddingSeasonalityAdjustmentsResponse
         */
        create: (biddingSeasonalityAdjustments: (resources.IBiddingSeasonalityAdjustment | resources.BiddingSeasonalityAdjustment)[], options?: Partial<Pick<services.IMutateBiddingSeasonalityAdjustmentsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateBiddingSeasonalityAdjustmentsResponse>;
        /**
         * @description update resources of type resources.IBiddingSeasonalityAdjustment
         * @returns services.MutateBiddingSeasonalityAdjustmentsResponse
         */
        update: (biddingSeasonalityAdjustments: (resources.IBiddingSeasonalityAdjustment | resources.BiddingSeasonalityAdjustment)[], options?: Partial<Pick<services.IMutateBiddingSeasonalityAdjustmentsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateBiddingSeasonalityAdjustmentsResponse>;
        /**
         * @description remove resources of type string
         * @returns services.MutateBiddingSeasonalityAdjustmentsResponse
         */
        remove: (biddingSeasonalityAdjustments: string[], options?: Partial<Pick<services.IMutateBiddingSeasonalityAdjustmentsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateBiddingSeasonalityAdjustmentsResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/BiddingStrategyService
     */
    get biddingStrategies(): {
        /**
         * @description create resources of type resources.IBiddingStrategy
         * @returns services.MutateBiddingStrategiesResponse
         */
        create: (biddingStrategies: (resources.IBiddingStrategy | resources.BiddingStrategy)[], options?: Partial<Pick<services.IMutateBiddingStrategiesRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateBiddingStrategiesResponse>;
        /**
         * @description update resources of type resources.IBiddingStrategy
         * @returns services.MutateBiddingStrategiesResponse
         */
        update: (biddingStrategies: (resources.IBiddingStrategy | resources.BiddingStrategy)[], options?: Partial<Pick<services.IMutateBiddingStrategiesRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateBiddingStrategiesResponse>;
        /**
         * @description remove resources of type string
         * @returns services.MutateBiddingStrategiesResponse
         */
        remove: (biddingStrategies: string[], options?: Partial<Pick<services.IMutateBiddingStrategiesRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateBiddingStrategiesResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/CampaignAssetService
     */
    get campaignAssets(): {
        /**
         * @description create resources of type resources.ICampaignAsset
         * @returns services.MutateCampaignAssetsResponse
         */
        create: (campaignAssets: (resources.ICampaignAsset | resources.CampaignAsset)[], options?: Partial<Pick<services.IMutateCampaignAssetsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateCampaignAssetsResponse>;
        /**
         * @description update resources of type resources.ICampaignAsset
         * @returns services.MutateCampaignAssetsResponse
         */
        update: (campaignAssets: (resources.ICampaignAsset | resources.CampaignAsset)[], options?: Partial<Pick<services.IMutateCampaignAssetsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateCampaignAssetsResponse>;
        /**
         * @description remove resources of type string
         * @returns services.MutateCampaignAssetsResponse
         */
        remove: (campaignAssets: string[], options?: Partial<Pick<services.IMutateCampaignAssetsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateCampaignAssetsResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/CampaignAssetSetService
     */
    get campaignAssetSets(): {
        /**
         * @description create resources of type resources.ICampaignAssetSet
         * @returns services.MutateCampaignAssetSetsResponse
         */
        create: (campaignAssetSets: (resources.ICampaignAssetSet | resources.CampaignAssetSet)[], options?: Partial<Pick<services.IMutateCampaignAssetSetsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateCampaignAssetSetsResponse>;
        /**
         * @description remove resources of type string
         * @returns services.MutateCampaignAssetSetsResponse
         */
        remove: (campaignAssetSets: string[], options?: Partial<Pick<services.IMutateCampaignAssetSetsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateCampaignAssetSetsResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/CampaignBidModifierService
     */
    get campaignBidModifiers(): {
        /**
         * @description create resources of type resources.ICampaignBidModifier
         * @returns services.MutateCampaignBidModifiersResponse
         */
        create: (campaignBidModifiers: (resources.ICampaignBidModifier | resources.CampaignBidModifier)[], options?: Partial<Pick<services.IMutateCampaignBidModifiersRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateCampaignBidModifiersResponse>;
        /**
         * @description update resources of type resources.ICampaignBidModifier
         * @returns services.MutateCampaignBidModifiersResponse
         */
        update: (campaignBidModifiers: (resources.ICampaignBidModifier | resources.CampaignBidModifier)[], options?: Partial<Pick<services.IMutateCampaignBidModifiersRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateCampaignBidModifiersResponse>;
        /**
         * @description remove resources of type string
         * @returns services.MutateCampaignBidModifiersResponse
         */
        remove: (campaignBidModifiers: string[], options?: Partial<Pick<services.IMutateCampaignBidModifiersRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateCampaignBidModifiersResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/CampaignBudgetService
     */
    get campaignBudgets(): {
        /**
         * @description create resources of type resources.ICampaignBudget
         * @returns services.MutateCampaignBudgetsResponse
         */
        create: (campaignBudgets: (resources.ICampaignBudget | resources.CampaignBudget)[], options?: Partial<Pick<services.IMutateCampaignBudgetsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateCampaignBudgetsResponse>;
        /**
         * @description update resources of type resources.ICampaignBudget
         * @returns services.MutateCampaignBudgetsResponse
         */
        update: (campaignBudgets: (resources.ICampaignBudget | resources.CampaignBudget)[], options?: Partial<Pick<services.IMutateCampaignBudgetsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateCampaignBudgetsResponse>;
        /**
         * @description remove resources of type string
         * @returns services.MutateCampaignBudgetsResponse
         */
        remove: (campaignBudgets: string[], options?: Partial<Pick<services.IMutateCampaignBudgetsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateCampaignBudgetsResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/CampaignConversionGoalService
     */
    get campaignConversionGoals(): {
        /**
         * @description update resources of type resources.ICampaignConversionGoal
         * @returns services.MutateCampaignConversionGoalsResponse
         */
        update: (campaignConversionGoals: (resources.ICampaignConversionGoal | resources.CampaignConversionGoal)[], options?: Partial<Pick<services.IMutateCampaignConversionGoalsRequest, "validate_only">>) => Promise<services.MutateCampaignConversionGoalsResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/CampaignCriterionService
     */
    get campaignCriteria(): {
        /**
         * @description create resources of type resources.ICampaignCriterion
         * @returns services.MutateCampaignCriteriaResponse
         */
        create: (campaignCriteria: (resources.ICampaignCriterion | resources.CampaignCriterion)[], options?: Partial<Pick<services.IMutateCampaignCriteriaRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateCampaignCriteriaResponse>;
        /**
         * @description update resources of type resources.ICampaignCriterion
         * @returns services.MutateCampaignCriteriaResponse
         */
        update: (campaignCriteria: (resources.ICampaignCriterion | resources.CampaignCriterion)[], options?: Partial<Pick<services.IMutateCampaignCriteriaRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateCampaignCriteriaResponse>;
        /**
         * @description remove resources of type string
         * @returns services.MutateCampaignCriteriaResponse
         */
        remove: (campaignCriteria: string[], options?: Partial<Pick<services.IMutateCampaignCriteriaRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateCampaignCriteriaResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/CampaignCustomizerService
     */
    get campaignCustomizers(): {
        /**
         * @description create resources of type resources.ICampaignCustomizer
         * @returns services.MutateCampaignCustomizersResponse
         */
        create: (campaignCustomizers: (resources.ICampaignCustomizer | resources.CampaignCustomizer)[], options?: Partial<Pick<services.IMutateCampaignCustomizersRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateCampaignCustomizersResponse>;
        /**
         * @description remove resources of type string
         * @returns services.MutateCampaignCustomizersResponse
         */
        remove: (campaignCustomizers: string[], options?: Partial<Pick<services.IMutateCampaignCustomizersRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateCampaignCustomizersResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/CampaignDraftService
     */
    get campaignDrafts(): {
        /**
         * @description create resources of type resources.ICampaignDraft
         * @returns services.MutateCampaignDraftsResponse
         */
        create: (campaignDrafts: (resources.ICampaignDraft | resources.CampaignDraft)[], options?: Partial<Pick<services.IMutateCampaignDraftsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateCampaignDraftsResponse>;
        /**
         * @description update resources of type resources.ICampaignDraft
         * @returns services.MutateCampaignDraftsResponse
         */
        update: (campaignDrafts: (resources.ICampaignDraft | resources.CampaignDraft)[], options?: Partial<Pick<services.IMutateCampaignDraftsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateCampaignDraftsResponse>;
        /**
         * @description remove resources of type string
         * @returns services.MutateCampaignDraftsResponse
         */
        remove: (campaignDrafts: string[], options?: Partial<Pick<services.IMutateCampaignDraftsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateCampaignDraftsResponse>;
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/CampaignDraftService#promotecampaigndraft
         */
        promoteCampaignDraft: (request: services.PromoteCampaignDraftRequest) => Promise<longrunning.Operation>;
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/CampaignDraftService#listcampaigndraftasyncerrors
         */
        listCampaignDraftAsyncErrors: (request: services.ListCampaignDraftAsyncErrorsRequest) => Promise<services.ListCampaignDraftAsyncErrorsResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/CampaignGroupService
     */
    get campaignGroups(): {
        /**
         * @description create resources of type resources.ICampaignGroup
         * @returns services.MutateCampaignGroupsResponse
         */
        create: (campaignGroups: (resources.ICampaignGroup | resources.CampaignGroup)[], options?: Partial<Pick<services.IMutateCampaignGroupsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateCampaignGroupsResponse>;
        /**
         * @description update resources of type resources.ICampaignGroup
         * @returns services.MutateCampaignGroupsResponse
         */
        update: (campaignGroups: (resources.ICampaignGroup | resources.CampaignGroup)[], options?: Partial<Pick<services.IMutateCampaignGroupsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateCampaignGroupsResponse>;
        /**
         * @description remove resources of type string
         * @returns services.MutateCampaignGroupsResponse
         */
        remove: (campaignGroups: string[], options?: Partial<Pick<services.IMutateCampaignGroupsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateCampaignGroupsResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/CampaignLabelService
     */
    get campaignLabels(): {
        /**
         * @description create resources of type resources.ICampaignLabel
         * @returns services.MutateCampaignLabelsResponse
         */
        create: (campaignLabels: (resources.ICampaignLabel | resources.CampaignLabel)[], options?: Partial<Pick<services.IMutateCampaignLabelsRequest, "validate_only" | "partial_failure">>) => Promise<services.MutateCampaignLabelsResponse>;
        /**
         * @description remove resources of type string
         * @returns services.MutateCampaignLabelsResponse
         */
        remove: (campaignLabels: string[], options?: Partial<Pick<services.IMutateCampaignLabelsRequest, "validate_only" | "partial_failure">>) => Promise<services.MutateCampaignLabelsResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/CampaignService
     */
    get campaigns(): {
        /**
         * @description create resources of type resources.ICampaign
         * @returns services.MutateCampaignsResponse
         */
        create: (campaigns: (resources.ICampaign | resources.Campaign)[], options?: Partial<Pick<services.IMutateCampaignsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateCampaignsResponse>;
        /**
         * @description update resources of type resources.ICampaign
         * @returns services.MutateCampaignsResponse
         */
        update: (campaigns: (resources.ICampaign | resources.Campaign)[], options?: Partial<Pick<services.IMutateCampaignsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateCampaignsResponse>;
        /**
         * @description remove resources of type string
         * @returns services.MutateCampaignsResponse
         */
        remove: (campaigns: string[], options?: Partial<Pick<services.IMutateCampaignsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateCampaignsResponse>;
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/CampaignService#enablepmaxbrandguidelines
         */
        enablePMaxBrandGuidelines: (request: services.EnablePMaxBrandGuidelinesRequest) => Promise<services.EnablePMaxBrandGuidelinesResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/CampaignSharedSetService
     */
    get campaignSharedSets(): {
        /**
         * @description create resources of type resources.ICampaignSharedSet
         * @returns services.MutateCampaignSharedSetsResponse
         */
        create: (campaignSharedSets: (resources.ICampaignSharedSet | resources.CampaignSharedSet)[], options?: Partial<Pick<services.IMutateCampaignSharedSetsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateCampaignSharedSetsResponse>;
        /**
         * @description remove resources of type string
         * @returns services.MutateCampaignSharedSetsResponse
         */
        remove: (campaignSharedSets: string[], options?: Partial<Pick<services.IMutateCampaignSharedSetsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateCampaignSharedSetsResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/ConversionActionService
     */
    get conversionActions(): {
        /**
         * @description create resources of type resources.IConversionAction
         * @returns services.MutateConversionActionsResponse
         */
        create: (conversionActions: (resources.IConversionAction | resources.ConversionAction)[], options?: Partial<Pick<services.IMutateConversionActionsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateConversionActionsResponse>;
        /**
         * @description update resources of type resources.IConversionAction
         * @returns services.MutateConversionActionsResponse
         */
        update: (conversionActions: (resources.IConversionAction | resources.ConversionAction)[], options?: Partial<Pick<services.IMutateConversionActionsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateConversionActionsResponse>;
        /**
         * @description remove resources of type string
         * @returns services.MutateConversionActionsResponse
         */
        remove: (conversionActions: string[], options?: Partial<Pick<services.IMutateConversionActionsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateConversionActionsResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/ConversionCustomVariableService
     */
    get conversionCustomVariables(): {
        /**
         * @description create resources of type resources.IConversionCustomVariable
         * @returns services.MutateConversionCustomVariablesResponse
         */
        create: (conversionCustomVariables: (resources.IConversionCustomVariable | resources.ConversionCustomVariable)[], options?: Partial<Pick<services.IMutateConversionCustomVariablesRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateConversionCustomVariablesResponse>;
        /**
         * @description update resources of type resources.IConversionCustomVariable
         * @returns services.MutateConversionCustomVariablesResponse
         */
        update: (conversionCustomVariables: (resources.IConversionCustomVariable | resources.ConversionCustomVariable)[], options?: Partial<Pick<services.IMutateConversionCustomVariablesRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateConversionCustomVariablesResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/ConversionGoalCampaignConfigService
     */
    get conversionGoalCampaignConfigs(): {
        /**
         * @description update resources of type resources.IConversionGoalCampaignConfig
         * @returns services.MutateConversionGoalCampaignConfigsResponse
         */
        update: (conversionGoalCampaignConfigs: (resources.IConversionGoalCampaignConfig | resources.ConversionGoalCampaignConfig)[], options?: Partial<Pick<services.IMutateConversionGoalCampaignConfigsRequest, "validate_only" | "response_content_type">>) => Promise<services.MutateConversionGoalCampaignConfigsResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/ConversionValueRuleService
     */
    get conversionValueRules(): {
        /**
         * @description create resources of type resources.IConversionValueRule
         * @returns services.MutateConversionValueRulesResponse
         */
        create: (conversionValueRules: (resources.IConversionValueRule | resources.ConversionValueRule)[], options?: Partial<Pick<services.IMutateConversionValueRulesRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateConversionValueRulesResponse>;
        /**
         * @description update resources of type resources.IConversionValueRule
         * @returns services.MutateConversionValueRulesResponse
         */
        update: (conversionValueRules: (resources.IConversionValueRule | resources.ConversionValueRule)[], options?: Partial<Pick<services.IMutateConversionValueRulesRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateConversionValueRulesResponse>;
        /**
         * @description remove resources of type string
         * @returns services.MutateConversionValueRulesResponse
         */
        remove: (conversionValueRules: string[], options?: Partial<Pick<services.IMutateConversionValueRulesRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateConversionValueRulesResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/ConversionValueRuleSetService
     */
    get conversionValueRuleSets(): {
        /**
         * @description create resources of type resources.IConversionValueRuleSet
         * @returns services.MutateConversionValueRuleSetsResponse
         */
        create: (conversionValueRuleSets: (resources.IConversionValueRuleSet | resources.ConversionValueRuleSet)[], options?: Partial<Pick<services.IMutateConversionValueRuleSetsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateConversionValueRuleSetsResponse>;
        /**
         * @description update resources of type resources.IConversionValueRuleSet
         * @returns services.MutateConversionValueRuleSetsResponse
         */
        update: (conversionValueRuleSets: (resources.IConversionValueRuleSet | resources.ConversionValueRuleSet)[], options?: Partial<Pick<services.IMutateConversionValueRuleSetsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateConversionValueRuleSetsResponse>;
        /**
         * @description remove resources of type string
         * @returns services.MutateConversionValueRuleSetsResponse
         */
        remove: (conversionValueRuleSets: string[], options?: Partial<Pick<services.IMutateConversionValueRuleSetsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateConversionValueRuleSetsResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/CustomConversionGoalService
     */
    get customConversionGoals(): {
        /**
         * @description create resources of type resources.ICustomConversionGoal
         * @returns services.MutateCustomConversionGoalsResponse
         */
        create: (customConversionGoals: (resources.ICustomConversionGoal | resources.CustomConversionGoal)[], options?: Partial<Pick<services.IMutateCustomConversionGoalsRequest, "validate_only" | "response_content_type">>) => Promise<services.MutateCustomConversionGoalsResponse>;
        /**
         * @description update resources of type resources.ICustomConversionGoal
         * @returns services.MutateCustomConversionGoalsResponse
         */
        update: (customConversionGoals: (resources.ICustomConversionGoal | resources.CustomConversionGoal)[], options?: Partial<Pick<services.IMutateCustomConversionGoalsRequest, "validate_only" | "response_content_type">>) => Promise<services.MutateCustomConversionGoalsResponse>;
        /**
         * @description remove resources of type string
         * @returns services.MutateCustomConversionGoalsResponse
         */
        remove: (customConversionGoals: string[], options?: Partial<Pick<services.IMutateCustomConversionGoalsRequest, "validate_only" | "response_content_type">>) => Promise<services.MutateCustomConversionGoalsResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/CustomerAssetService
     */
    get customerAssets(): {
        /**
         * @description create resources of type resources.ICustomerAsset
         * @returns services.MutateCustomerAssetsResponse
         */
        create: (customerAssets: (resources.ICustomerAsset | resources.CustomerAsset)[], options?: Partial<Pick<services.IMutateCustomerAssetsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateCustomerAssetsResponse>;
        /**
         * @description update resources of type resources.ICustomerAsset
         * @returns services.MutateCustomerAssetsResponse
         */
        update: (customerAssets: (resources.ICustomerAsset | resources.CustomerAsset)[], options?: Partial<Pick<services.IMutateCustomerAssetsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateCustomerAssetsResponse>;
        /**
         * @description remove resources of type string
         * @returns services.MutateCustomerAssetsResponse
         */
        remove: (customerAssets: string[], options?: Partial<Pick<services.IMutateCustomerAssetsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateCustomerAssetsResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/CustomerConversionGoalService
     */
    get customerConversionGoals(): {
        /**
         * @description update resources of type resources.ICustomerConversionGoal
         * @returns services.MutateCustomerConversionGoalsResponse
         */
        update: (customerConversionGoals: (resources.ICustomerConversionGoal | resources.CustomerConversionGoal)[], options?: Partial<Pick<services.IMutateCustomerConversionGoalsRequest, "validate_only">>) => Promise<services.MutateCustomerConversionGoalsResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/CustomerCustomizerService
     */
    get customerCustomizers(): {
        /**
         * @description create resources of type resources.ICustomerCustomizer
         * @returns services.MutateCustomerCustomizersResponse
         */
        create: (customerCustomizers: (resources.ICustomerCustomizer | resources.CustomerCustomizer)[], options?: Partial<Pick<services.IMutateCustomerCustomizersRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateCustomerCustomizersResponse>;
        /**
         * @description remove resources of type string
         * @returns services.MutateCustomerCustomizersResponse
         */
        remove: (customerCustomizers: string[], options?: Partial<Pick<services.IMutateCustomerCustomizersRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateCustomerCustomizersResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/CustomerLabelService
     */
    get customerLabels(): {
        /**
         * @description create resources of type resources.ICustomerLabel
         * @returns services.MutateCustomerLabelsResponse
         */
        create: (customerLabels: (resources.ICustomerLabel | resources.CustomerLabel)[], options?: Partial<Pick<services.IMutateCustomerLabelsRequest, "validate_only" | "partial_failure">>) => Promise<services.MutateCustomerLabelsResponse>;
        /**
         * @description remove resources of type string
         * @returns services.MutateCustomerLabelsResponse
         */
        remove: (customerLabels: string[], options?: Partial<Pick<services.IMutateCustomerLabelsRequest, "validate_only" | "partial_failure">>) => Promise<services.MutateCustomerLabelsResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/CustomerNegativeCriterionService
     */
    get customerNegativeCriteria(): {
        /**
         * @description create resources of type resources.ICustomerNegativeCriterion
         * @returns services.MutateCustomerNegativeCriteriaResponse
         */
        create: (customerNegativeCriteria: (resources.ICustomerNegativeCriterion | resources.CustomerNegativeCriterion)[], options?: Partial<Pick<services.IMutateCustomerNegativeCriteriaRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateCustomerNegativeCriteriaResponse>;
        /**
         * @description remove resources of type string
         * @returns services.MutateCustomerNegativeCriteriaResponse
         */
        remove: (customerNegativeCriteria: string[], options?: Partial<Pick<services.IMutateCustomerNegativeCriteriaRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateCustomerNegativeCriteriaResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/CustomerService
     */
    get customers(): {
        /**
         * @description update resources of type resources.ICustomer
         * @returns services.MutateCustomerResponse
         */
        update: (customers: (resources.ICustomer | resources.Customer)[], options?: Partial<Pick<services.IMutateCustomerRequest, "validate_only" | "response_content_type">>) => Promise<services.MutateCustomerResponse>;
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/CustomerService#listaccessiblecustomers
         */
        listAccessibleCustomers: (request: services.ListAccessibleCustomersRequest) => Promise<services.ListAccessibleCustomersResponse>;
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/CustomerService#createcustomerclient
         */
        createCustomerClient: (request: services.CreateCustomerClientRequest) => Promise<services.CreateCustomerClientResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/CustomizerAttributeService
     */
    get customizerAttributes(): {
        /**
         * @description create resources of type resources.ICustomizerAttribute
         * @returns services.MutateCustomizerAttributesResponse
         */
        create: (customizerAttributes: (resources.ICustomizerAttribute | resources.CustomizerAttribute)[], options?: Partial<Pick<services.IMutateCustomizerAttributesRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateCustomizerAttributesResponse>;
        /**
         * @description remove resources of type string
         * @returns services.MutateCustomizerAttributesResponse
         */
        remove: (customizerAttributes: string[], options?: Partial<Pick<services.IMutateCustomizerAttributesRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateCustomizerAttributesResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/ExperimentArmService
     */
    get experimentArms(): {
        /**
         * @description create resources of type resources.IExperimentArm
         * @returns services.MutateExperimentArmsResponse
         */
        create: (experimentArms: (resources.IExperimentArm | resources.ExperimentArm)[], options?: Partial<Pick<services.IMutateExperimentArmsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateExperimentArmsResponse>;
        /**
         * @description update resources of type resources.IExperimentArm
         * @returns services.MutateExperimentArmsResponse
         */
        update: (experimentArms: (resources.IExperimentArm | resources.ExperimentArm)[], options?: Partial<Pick<services.IMutateExperimentArmsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateExperimentArmsResponse>;
        /**
         * @description remove resources of type string
         * @returns services.MutateExperimentArmsResponse
         */
        remove: (experimentArms: string[], options?: Partial<Pick<services.IMutateExperimentArmsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateExperimentArmsResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/ExperimentService
     */
    get experiments(): {
        /**
         * @description create resources of type resources.IExperiment
         * @returns services.MutateExperimentsResponse
         */
        create: (experiments: (resources.IExperiment | resources.Experiment)[], options?: Partial<Pick<services.IMutateExperimentsRequest, "validate_only" | "partial_failure">>) => Promise<services.MutateExperimentsResponse>;
        /**
         * @description update resources of type resources.IExperiment
         * @returns services.MutateExperimentsResponse
         */
        update: (experiments: (resources.IExperiment | resources.Experiment)[], options?: Partial<Pick<services.IMutateExperimentsRequest, "validate_only" | "partial_failure">>) => Promise<services.MutateExperimentsResponse>;
        /**
         * @description remove resources of type string
         * @returns services.MutateExperimentsResponse
         */
        remove: (experiments: string[], options?: Partial<Pick<services.IMutateExperimentsRequest, "validate_only" | "partial_failure">>) => Promise<services.MutateExperimentsResponse>;
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/ExperimentService#endexperiment
         */
        endExperiment: (request: services.EndExperimentRequest) => Promise<protobuf.Empty>;
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/ExperimentService#listexperimentasyncerrors
         */
        listExperimentAsyncErrors: (request: services.ListExperimentAsyncErrorsRequest) => Promise<services.ListExperimentAsyncErrorsResponse>;
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/ExperimentService#graduateexperiment
         */
        graduateExperiment: (request: services.GraduateExperimentRequest) => Promise<protobuf.Empty>;
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/ExperimentService#scheduleexperiment
         */
        scheduleExperiment: (request: services.ScheduleExperimentRequest) => Promise<longrunning.Operation>;
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/ExperimentService#promoteexperiment
         */
        promoteExperiment: (request: services.PromoteExperimentRequest) => Promise<longrunning.Operation>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/KeywordPlanAdGroupKeywordService
     */
    get keywordPlanAdGroupKeywords(): {
        /**
         * @description create resources of type resources.IKeywordPlanAdGroupKeyword
         * @returns services.MutateKeywordPlanAdGroupKeywordsResponse
         */
        create: (keywordPlanAdGroupKeywords: (resources.IKeywordPlanAdGroupKeyword | resources.KeywordPlanAdGroupKeyword)[], options?: Partial<Pick<services.IMutateKeywordPlanAdGroupKeywordsRequest, "validate_only" | "partial_failure">>) => Promise<services.MutateKeywordPlanAdGroupKeywordsResponse>;
        /**
         * @description update resources of type resources.IKeywordPlanAdGroupKeyword
         * @returns services.MutateKeywordPlanAdGroupKeywordsResponse
         */
        update: (keywordPlanAdGroupKeywords: (resources.IKeywordPlanAdGroupKeyword | resources.KeywordPlanAdGroupKeyword)[], options?: Partial<Pick<services.IMutateKeywordPlanAdGroupKeywordsRequest, "validate_only" | "partial_failure">>) => Promise<services.MutateKeywordPlanAdGroupKeywordsResponse>;
        /**
         * @description remove resources of type string
         * @returns services.MutateKeywordPlanAdGroupKeywordsResponse
         */
        remove: (keywordPlanAdGroupKeywords: string[], options?: Partial<Pick<services.IMutateKeywordPlanAdGroupKeywordsRequest, "validate_only" | "partial_failure">>) => Promise<services.MutateKeywordPlanAdGroupKeywordsResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/KeywordPlanAdGroupService
     */
    get keywordPlanAdGroups(): {
        /**
         * @description create resources of type resources.IKeywordPlanAdGroup
         * @returns services.MutateKeywordPlanAdGroupsResponse
         */
        create: (keywordPlanAdGroups: (resources.IKeywordPlanAdGroup | resources.KeywordPlanAdGroup)[], options?: Partial<Pick<services.IMutateKeywordPlanAdGroupsRequest, "validate_only" | "partial_failure">>) => Promise<services.MutateKeywordPlanAdGroupsResponse>;
        /**
         * @description update resources of type resources.IKeywordPlanAdGroup
         * @returns services.MutateKeywordPlanAdGroupsResponse
         */
        update: (keywordPlanAdGroups: (resources.IKeywordPlanAdGroup | resources.KeywordPlanAdGroup)[], options?: Partial<Pick<services.IMutateKeywordPlanAdGroupsRequest, "validate_only" | "partial_failure">>) => Promise<services.MutateKeywordPlanAdGroupsResponse>;
        /**
         * @description remove resources of type string
         * @returns services.MutateKeywordPlanAdGroupsResponse
         */
        remove: (keywordPlanAdGroups: string[], options?: Partial<Pick<services.IMutateKeywordPlanAdGroupsRequest, "validate_only" | "partial_failure">>) => Promise<services.MutateKeywordPlanAdGroupsResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/KeywordPlanCampaignKeywordService
     */
    get keywordPlanCampaignKeywords(): {
        /**
         * @description create resources of type resources.IKeywordPlanCampaignKeyword
         * @returns services.MutateKeywordPlanCampaignKeywordsResponse
         */
        create: (keywordPlanCampaignKeywords: (resources.IKeywordPlanCampaignKeyword | resources.KeywordPlanCampaignKeyword)[], options?: Partial<Pick<services.IMutateKeywordPlanCampaignKeywordsRequest, "validate_only" | "partial_failure">>) => Promise<services.MutateKeywordPlanCampaignKeywordsResponse>;
        /**
         * @description update resources of type resources.IKeywordPlanCampaignKeyword
         * @returns services.MutateKeywordPlanCampaignKeywordsResponse
         */
        update: (keywordPlanCampaignKeywords: (resources.IKeywordPlanCampaignKeyword | resources.KeywordPlanCampaignKeyword)[], options?: Partial<Pick<services.IMutateKeywordPlanCampaignKeywordsRequest, "validate_only" | "partial_failure">>) => Promise<services.MutateKeywordPlanCampaignKeywordsResponse>;
        /**
         * @description remove resources of type string
         * @returns services.MutateKeywordPlanCampaignKeywordsResponse
         */
        remove: (keywordPlanCampaignKeywords: string[], options?: Partial<Pick<services.IMutateKeywordPlanCampaignKeywordsRequest, "validate_only" | "partial_failure">>) => Promise<services.MutateKeywordPlanCampaignKeywordsResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/KeywordPlanCampaignService
     */
    get keywordPlanCampaigns(): {
        /**
         * @description create resources of type resources.IKeywordPlanCampaign
         * @returns services.MutateKeywordPlanCampaignsResponse
         */
        create: (keywordPlanCampaigns: (resources.IKeywordPlanCampaign | resources.KeywordPlanCampaign)[], options?: Partial<Pick<services.IMutateKeywordPlanCampaignsRequest, "validate_only" | "partial_failure">>) => Promise<services.MutateKeywordPlanCampaignsResponse>;
        /**
         * @description update resources of type resources.IKeywordPlanCampaign
         * @returns services.MutateKeywordPlanCampaignsResponse
         */
        update: (keywordPlanCampaigns: (resources.IKeywordPlanCampaign | resources.KeywordPlanCampaign)[], options?: Partial<Pick<services.IMutateKeywordPlanCampaignsRequest, "validate_only" | "partial_failure">>) => Promise<services.MutateKeywordPlanCampaignsResponse>;
        /**
         * @description remove resources of type string
         * @returns services.MutateKeywordPlanCampaignsResponse
         */
        remove: (keywordPlanCampaigns: string[], options?: Partial<Pick<services.IMutateKeywordPlanCampaignsRequest, "validate_only" | "partial_failure">>) => Promise<services.MutateKeywordPlanCampaignsResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/KeywordPlanService
     */
    get keywordPlans(): {
        /**
         * @description create resources of type resources.IKeywordPlan
         * @returns services.MutateKeywordPlansResponse
         */
        create: (keywordPlans: (resources.IKeywordPlan | resources.KeywordPlan)[], options?: Partial<Pick<services.IMutateKeywordPlansRequest, "validate_only" | "partial_failure">>) => Promise<services.MutateKeywordPlansResponse>;
        /**
         * @description update resources of type resources.IKeywordPlan
         * @returns services.MutateKeywordPlansResponse
         */
        update: (keywordPlans: (resources.IKeywordPlan | resources.KeywordPlan)[], options?: Partial<Pick<services.IMutateKeywordPlansRequest, "validate_only" | "partial_failure">>) => Promise<services.MutateKeywordPlansResponse>;
        /**
         * @description remove resources of type string
         * @returns services.MutateKeywordPlansResponse
         */
        remove: (keywordPlans: string[], options?: Partial<Pick<services.IMutateKeywordPlansRequest, "validate_only" | "partial_failure">>) => Promise<services.MutateKeywordPlansResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/LabelService
     */
    get labels(): {
        /**
         * @description create resources of type resources.ILabel
         * @returns services.MutateLabelsResponse
         */
        create: (labels: (resources.ILabel | resources.Label)[], options?: Partial<Pick<services.IMutateLabelsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateLabelsResponse>;
        /**
         * @description update resources of type resources.ILabel
         * @returns services.MutateLabelsResponse
         */
        update: (labels: (resources.ILabel | resources.Label)[], options?: Partial<Pick<services.IMutateLabelsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateLabelsResponse>;
        /**
         * @description remove resources of type string
         * @returns services.MutateLabelsResponse
         */
        remove: (labels: string[], options?: Partial<Pick<services.IMutateLabelsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateLabelsResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/RecommendationSubscriptionService
     */
    get recommendationSubscriptions(): {
        /**
         * @description create resources of type resources.IRecommendationSubscription
         * @returns services.MutateRecommendationSubscriptionResponse
         */
        create: (recommendationSubscriptions: (resources.IRecommendationSubscription | resources.RecommendationSubscription)[], options?: Partial<Pick<services.IMutateRecommendationSubscriptionRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateRecommendationSubscriptionResponse>;
        /**
         * @description update resources of type resources.IRecommendationSubscription
         * @returns services.MutateRecommendationSubscriptionResponse
         */
        update: (recommendationSubscriptions: (resources.IRecommendationSubscription | resources.RecommendationSubscription)[], options?: Partial<Pick<services.IMutateRecommendationSubscriptionRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateRecommendationSubscriptionResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/RemarketingActionService
     */
    get remarketingActions(): {
        /**
         * @description create resources of type resources.IRemarketingAction
         * @returns services.MutateRemarketingActionsResponse
         */
        create: (remarketingActions: (resources.IRemarketingAction | resources.RemarketingAction)[], options?: Partial<Pick<services.IMutateRemarketingActionsRequest, "validate_only" | "partial_failure">>) => Promise<services.MutateRemarketingActionsResponse>;
        /**
         * @description update resources of type resources.IRemarketingAction
         * @returns services.MutateRemarketingActionsResponse
         */
        update: (remarketingActions: (resources.IRemarketingAction | resources.RemarketingAction)[], options?: Partial<Pick<services.IMutateRemarketingActionsRequest, "validate_only" | "partial_failure">>) => Promise<services.MutateRemarketingActionsResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/SharedCriterionService
     */
    get sharedCriteria(): {
        /**
         * @description create resources of type resources.ISharedCriterion
         * @returns services.MutateSharedCriteriaResponse
         */
        create: (sharedCriteria: (resources.ISharedCriterion | resources.SharedCriterion)[], options?: Partial<Pick<services.IMutateSharedCriteriaRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateSharedCriteriaResponse>;
        /**
         * @description remove resources of type string
         * @returns services.MutateSharedCriteriaResponse
         */
        remove: (sharedCriteria: string[], options?: Partial<Pick<services.IMutateSharedCriteriaRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateSharedCriteriaResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/SharedSetService
     */
    get sharedSets(): {
        /**
         * @description create resources of type resources.ISharedSet
         * @returns services.MutateSharedSetsResponse
         */
        create: (sharedSets: (resources.ISharedSet | resources.SharedSet)[], options?: Partial<Pick<services.IMutateSharedSetsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateSharedSetsResponse>;
        /**
         * @description update resources of type resources.ISharedSet
         * @returns services.MutateSharedSetsResponse
         */
        update: (sharedSets: (resources.ISharedSet | resources.SharedSet)[], options?: Partial<Pick<services.IMutateSharedSetsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateSharedSetsResponse>;
        /**
         * @description remove resources of type string
         * @returns services.MutateSharedSetsResponse
         */
        remove: (sharedSets: string[], options?: Partial<Pick<services.IMutateSharedSetsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateSharedSetsResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/SmartCampaignSettingService
     */
    get smartCampaignSettings(): {
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/SmartCampaignSettingService#getsmartcampaignstatus
         */
        getSmartCampaignStatus: (request: services.GetSmartCampaignStatusRequest) => Promise<services.GetSmartCampaignStatusResponse>;
        /**
         * @description update resources of type resources.ISmartCampaignSetting
         * @returns services.MutateSmartCampaignSettingsResponse
         */
        update: (smartCampaignSettings: (resources.ISmartCampaignSetting | resources.SmartCampaignSetting)[], options?: Partial<Pick<services.IMutateSmartCampaignSettingsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateSmartCampaignSettingsResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/UserListService
     */
    get userLists(): {
        /**
         * @description create resources of type resources.IUserList
         * @returns services.MutateUserListsResponse
         */
        create: (userLists: (resources.IUserList | resources.UserList)[], options?: Partial<Pick<services.IMutateUserListsRequest, "validate_only" | "partial_failure">>) => Promise<services.MutateUserListsResponse>;
        /**
         * @description update resources of type resources.IUserList
         * @returns services.MutateUserListsResponse
         */
        update: (userLists: (resources.IUserList | resources.UserList)[], options?: Partial<Pick<services.IMutateUserListsRequest, "validate_only" | "partial_failure">>) => Promise<services.MutateUserListsResponse>;
        /**
         * @description remove resources of type string
         * @returns services.MutateUserListsResponse
         */
        remove: (userLists: string[], options?: Partial<Pick<services.IMutateUserListsRequest, "validate_only" | "partial_failure">>) => Promise<services.MutateUserListsResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/BillingSetupService
     */
    get billingSetups(): {
        /**
         * @description create resources of type resources.IBillingSetup
         * @returns services.MutateBillingSetupResponse
         */
        create: (billingSetups: (resources.IBillingSetup | resources.BillingSetup)[], options?: never) => Promise<services.MutateBillingSetupResponse>;
        /**
         * @description remove resources of type string
         * @returns services.MutateBillingSetupResponse
         */
        remove: (billingSetups: string[], options?: never) => Promise<services.MutateBillingSetupResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/BrandSuggestionService
     */
    get brandSuggestions(): {
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/BrandSuggestionService#suggestbrands
         */
        suggestBrands: (request: services.SuggestBrandsRequest) => Promise<services.SuggestBrandsResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/CampaignLifecycleGoalService
     */
    get campaignLifecycleGoals(): {
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/CampaignLifecycleGoalService#configurecampaignlifecyclegoals
         */
        configureCampaignLifecycleGoals: (request: services.ConfigureCampaignLifecycleGoalsRequest) => Promise<services.ConfigureCampaignLifecycleGoalsResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/ContentCreatorInsightsService
     */
    get contentCreatorInsights(): {
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/ContentCreatorInsightsService#generatecreatorinsights
         */
        generateCreatorInsights: (request: services.GenerateCreatorInsightsRequest) => Promise<services.GenerateCreatorInsightsResponse>;
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/ContentCreatorInsightsService#generatetrendinginsights
         */
        generateTrendingInsights: (request: services.GenerateTrendingInsightsRequest) => Promise<services.GenerateTrendingInsightsResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/ConversionAdjustmentUploadService
     */
    get conversionAdjustmentUploads(): {
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/ConversionAdjustmentUploadService#uploadconversionadjustments
         */
        uploadConversionAdjustments: (request: services.UploadConversionAdjustmentsRequest) => Promise<services.UploadConversionAdjustmentsResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/ConversionUploadService
     */
    get conversionUploads(): {
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/ConversionUploadService#uploadclickconversions
         */
        uploadClickConversions: (request: services.UploadClickConversionsRequest) => Promise<services.UploadClickConversionsResponse>;
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/ConversionUploadService#uploadcallconversions
         */
        uploadCallConversions: (request: services.UploadCallConversionsRequest) => Promise<services.UploadCallConversionsResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/CustomAudienceService
     */
    get customAudiences(): {
        /**
         * @description create resources of type resources.ICustomAudience
         * @returns services.MutateCustomAudiencesResponse
         */
        create: (customAudiences: (resources.ICustomAudience | resources.CustomAudience)[], options?: Partial<Pick<services.IMutateCustomAudiencesRequest, "validate_only">>) => Promise<services.MutateCustomAudiencesResponse>;
        /**
         * @description update resources of type resources.ICustomAudience
         * @returns services.MutateCustomAudiencesResponse
         */
        update: (customAudiences: (resources.ICustomAudience | resources.CustomAudience)[], options?: Partial<Pick<services.IMutateCustomAudiencesRequest, "validate_only">>) => Promise<services.MutateCustomAudiencesResponse>;
        /**
         * @description remove resources of type string
         * @returns services.MutateCustomAudiencesResponse
         */
        remove: (customAudiences: string[], options?: Partial<Pick<services.IMutateCustomAudiencesRequest, "validate_only">>) => Promise<services.MutateCustomAudiencesResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/CustomInterestService
     */
    get customInterests(): {
        /**
         * @description create resources of type resources.ICustomInterest
         * @returns services.MutateCustomInterestsResponse
         */
        create: (customInterests: (resources.ICustomInterest | resources.CustomInterest)[], options?: Partial<Pick<services.IMutateCustomInterestsRequest, "validate_only">>) => Promise<services.MutateCustomInterestsResponse>;
        /**
         * @description update resources of type resources.ICustomInterest
         * @returns services.MutateCustomInterestsResponse
         */
        update: (customInterests: (resources.ICustomInterest | resources.CustomInterest)[], options?: Partial<Pick<services.IMutateCustomInterestsRequest, "validate_only">>) => Promise<services.MutateCustomInterestsResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/CustomerAssetSetService
     */
    get customerAssetSets(): {
        /**
         * @description create resources of type resources.ICustomerAssetSet
         * @returns services.MutateCustomerAssetSetsResponse
         */
        create: (customerAssetSets: (resources.ICustomerAssetSet | resources.CustomerAssetSet)[], options?: Partial<Pick<services.IMutateCustomerAssetSetsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateCustomerAssetSetsResponse>;
        /**
         * @description remove resources of type string
         * @returns services.MutateCustomerAssetSetsResponse
         */
        remove: (customerAssetSets: string[], options?: Partial<Pick<services.IMutateCustomerAssetSetsRequest, "validate_only" | "partial_failure" | "response_content_type">>) => Promise<services.MutateCustomerAssetSetsResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/CustomerClientLinkService
     */
    get customerClientLinks(): {
        /**
         * @description create resources of type resources.ICustomerClientLink
         * @returns services.MutateCustomerClientLinkResponse
         */
        create: (customerClientLinks: (resources.ICustomerClientLink | resources.CustomerClientLink)[], options?: Partial<Pick<services.IMutateCustomerClientLinkRequest, "validate_only">>) => Promise<services.MutateCustomerClientLinkResponse>;
        /**
         * @description update resources of type resources.ICustomerClientLink
         * @returns services.MutateCustomerClientLinkResponse
         */
        update: (customerClientLinks: (resources.ICustomerClientLink | resources.CustomerClientLink)[], options?: Partial<Pick<services.IMutateCustomerClientLinkRequest, "validate_only">>) => Promise<services.MutateCustomerClientLinkResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/CustomerLifecycleGoalService
     */
    get customerLifecycleGoals(): {
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/CustomerLifecycleGoalService#configurecustomerlifecyclegoals
         */
        configureCustomerLifecycleGoals: (request: services.ConfigureCustomerLifecycleGoalsRequest) => Promise<services.ConfigureCustomerLifecycleGoalsResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/CustomerManagerLinkService
     */
    get customerManagerLinks(): {
        /**
         * @description update resources of type resources.ICustomerManagerLink
         * @returns services.MutateCustomerManagerLinkResponse
         */
        update: (customerManagerLinks: (resources.ICustomerManagerLink | resources.CustomerManagerLink)[], options?: Partial<Pick<services.IMutateCustomerManagerLinkRequest, "validate_only">>) => Promise<services.MutateCustomerManagerLinkResponse>;
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/CustomerManagerLinkService#movemanagerlink
         */
        moveManagerLink: (request: services.MoveManagerLinkRequest) => Promise<services.MoveManagerLinkResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/CustomerSkAdNetworkConversionValueSchemaService
     */
    get customerSkAdNetworkConversionValueSchemas(): {
        /**
         * @description update resources of type resources.ICustomerSkAdNetworkConversionValueSchema
         * @returns services.MutateCustomerSkAdNetworkConversionValueSchemaResponse
         */
        update: (customerSkAdNetworkConversionValueSchemas: (resources.ICustomerSkAdNetworkConversionValueSchema | resources.CustomerSkAdNetworkConversionValueSchema)[], options?: Partial<Pick<services.IMutateCustomerSkAdNetworkConversionValueSchemaRequest, "validate_only" | "enable_warnings">>) => Promise<services.MutateCustomerSkAdNetworkConversionValueSchemaResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/CustomerUserAccessInvitationService
     */
    get customerUserAccessInvitations(): {
        /**
         * @description create resources of type resources.ICustomerUserAccessInvitation
         * @returns services.MutateCustomerUserAccessInvitationResponse
         */
        create: (customerUserAccessInvitations: (resources.ICustomerUserAccessInvitation | resources.CustomerUserAccessInvitation)[], options?: never) => Promise<services.MutateCustomerUserAccessInvitationResponse>;
        /**
         * @description remove resources of type string
         * @returns services.MutateCustomerUserAccessInvitationResponse
         */
        remove: (customerUserAccessInvitations: string[], options?: never) => Promise<services.MutateCustomerUserAccessInvitationResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/CustomerUserAccessService
     */
    get customerUserAccesses(): {
        /**
         * @description update resources of type resources.ICustomerUserAccess
         * @returns services.MutateCustomerUserAccessResponse
         */
        update: (customerUserAccesses: (resources.ICustomerUserAccess | resources.CustomerUserAccess)[], options?: never) => Promise<services.MutateCustomerUserAccessResponse>;
        /**
         * @description remove resources of type string
         * @returns services.MutateCustomerUserAccessResponse
         */
        remove: (customerUserAccesses: string[], options?: never) => Promise<services.MutateCustomerUserAccessResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/DataLinkService
     */
    get dataLinks(): {
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/DataLinkService#createdatalink
         */
        createDataLink: (request: services.CreateDataLinkRequest) => Promise<services.CreateDataLinkResponse>;
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/DataLinkService#removedatalink
         */
        removeDataLink: (request: services.RemoveDataLinkRequest) => Promise<services.RemoveDataLinkResponse>;
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/DataLinkService#updatedatalink
         */
        updateDataLink: (request: services.UpdateDataLinkRequest) => Promise<services.UpdateDataLinkResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/GeoTargetConstantService
     */
    get geoTargetConstants(): {
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/GeoTargetConstantService#suggestgeotargetconstants
         */
        suggestGeoTargetConstants: (request: services.SuggestGeoTargetConstantsRequest) => Promise<services.SuggestGeoTargetConstantsResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/IdentityVerificationService
     */
    get identityVerifications(): {
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/IdentityVerificationService#startidentityverification
         */
        startIdentityVerification: (request: services.StartIdentityVerificationRequest) => Promise<protobuf.Empty>;
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/IdentityVerificationService#getidentityverification
         */
        getIdentityVerification: (request: services.GetIdentityVerificationRequest) => Promise<services.GetIdentityVerificationResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/InvoiceService
     */
    get invoices(): {
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/InvoiceService#listinvoices
         */
        listInvoices: (request: services.ListInvoicesRequest) => Promise<services.ListInvoicesResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/KeywordPlanIdeaService
     */
    get keywordPlanIdeas(): {
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/KeywordPlanIdeaService#generatekeywordideas
         */
        generateKeywordIdeas: (request: services.GenerateKeywordIdeasRequest) => Promise<services.GenerateKeywordIdeaResponse>;
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/KeywordPlanIdeaService#generatekeywordhistoricalmetrics
         */
        generateKeywordHistoricalMetrics: (request: services.GenerateKeywordHistoricalMetricsRequest) => Promise<services.GenerateKeywordHistoricalMetricsResponse>;
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/KeywordPlanIdeaService#generateadgroupthemes
         */
        generateAdGroupThemes: (request: services.GenerateAdGroupThemesRequest) => Promise<services.GenerateAdGroupThemesResponse>;
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/KeywordPlanIdeaService#generatekeywordforecastmetrics
         */
        generateKeywordForecastMetrics: (request: services.GenerateKeywordForecastMetricsRequest) => Promise<services.GenerateKeywordForecastMetricsResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/KeywordThemeConstantService
     */
    get keywordThemeConstants(): {
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/KeywordThemeConstantService#suggestkeywordthemeconstants
         */
        suggestKeywordThemeConstants: (request: services.SuggestKeywordThemeConstantsRequest) => Promise<services.SuggestKeywordThemeConstantsResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/LocalServicesLeadService
     */
    get localsLeadServices(): {
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/LocalServicesLeadService#appendleadconversation
         */
        appendLeadConversation: (request: services.AppendLeadConversationRequest) => Promise<services.AppendLeadConversationResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/OfflineUserDataJobService
     */
    get offlineUserDataJobs(): {
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/OfflineUserDataJobService#createofflineuserdatajob
         */
        createOfflineUserDataJob: (request: services.CreateOfflineUserDataJobRequest) => Promise<services.CreateOfflineUserDataJobResponse>;
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/OfflineUserDataJobService#addofflineuserdatajoboperations
         */
        addOfflineUserDataJobOperations: (request: services.AddOfflineUserDataJobOperationsRequest) => Promise<services.AddOfflineUserDataJobOperationsResponse>;
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/OfflineUserDataJobService#runofflineuserdatajob
         */
        runOfflineUserDataJob: (request: services.RunOfflineUserDataJobRequest) => Promise<longrunning.Operation>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/PaymentsAccountService
     */
    get paymentsAccounts(): {
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/PaymentsAccountService#listpaymentsaccounts
         */
        listPaymentsAccounts: (request: services.ListPaymentsAccountsRequest) => Promise<services.ListPaymentsAccountsResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/ProductLinkInvitationService
     */
    get productLinkInvitations(): {
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/ProductLinkInvitationService#createproductlinkinvitation
         */
        createProductLinkInvitation: (request: services.CreateProductLinkInvitationRequest) => Promise<services.CreateProductLinkInvitationResponse>;
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/ProductLinkInvitationService#updateproductlinkinvitation
         */
        updateProductLinkInvitation: (request: services.UpdateProductLinkInvitationRequest) => Promise<services.UpdateProductLinkInvitationResponse>;
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/ProductLinkInvitationService#removeproductlinkinvitation
         */
        removeProductLinkInvitation: (request: services.RemoveProductLinkInvitationRequest) => Promise<services.RemoveProductLinkInvitationResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/ProductLinkService
     */
    get productLinks(): {
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/ProductLinkService#createproductlink
         */
        createProductLink: (request: services.CreateProductLinkRequest) => Promise<services.CreateProductLinkResponse>;
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/ProductLinkService#removeproductlink
         */
        removeProductLink: (request: services.RemoveProductLinkRequest) => Promise<services.RemoveProductLinkResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/ReachPlanService
     */
    get reachPlans(): {
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/ReachPlanService#listplannablelocations
         */
        listPlannableLocations: (request: services.ListPlannableLocationsRequest) => Promise<services.ListPlannableLocationsResponse>;
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/ReachPlanService#listplannableproducts
         */
        listPlannableProducts: (request: services.ListPlannableProductsRequest) => Promise<services.ListPlannableProductsResponse>;
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/ReachPlanService#generatereachforecast
         */
        generateReachForecast: (request: services.GenerateReachForecastRequest) => Promise<services.GenerateReachForecastResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/RecommendationService
     */
    get recommendations(): {
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/RecommendationService#applyrecommendation
         */
        applyRecommendation: (request: services.ApplyRecommendationRequest) => Promise<services.ApplyRecommendationResponse>;
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/RecommendationService#dismissrecommendation
         */
        dismissRecommendation: (request: services.DismissRecommendationRequest) => Promise<services.DismissRecommendationResponse>;
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/RecommendationService#generaterecommendations
         */
        generateRecommendations: (request: services.GenerateRecommendationsRequest) => Promise<services.GenerateRecommendationsResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/ShareablePreviewService
     */
    get shareablePreviews(): {
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/ShareablePreviewService#generateshareablepreviews
         */
        generateShareablePreviews: (request: services.GenerateShareablePreviewsRequest) => Promise<services.GenerateShareablePreviewsResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/SmartCampaignSuggestService
     */
    get smartCampaignSuggests(): {
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/SmartCampaignSuggestService#suggestsmartcampaignbudgetoptions
         */
        suggestSmartCampaignBudgetOptions: (request: services.SuggestSmartCampaignBudgetOptionsRequest) => Promise<services.SuggestSmartCampaignBudgetOptionsResponse>;
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/SmartCampaignSuggestService#suggestsmartcampaignad
         */
        suggestSmartCampaignAd: (request: services.SuggestSmartCampaignAdRequest) => Promise<services.SuggestSmartCampaignAdResponse>;
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/SmartCampaignSuggestService#suggestkeywordthemes
         */
        suggestKeywordThemes: (request: services.SuggestKeywordThemesRequest) => Promise<services.SuggestKeywordThemesResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/ThirdPartyAppAnalyticsLinkService
     */
    get thirdPartyAppAnalyticsLinks(): {
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/ThirdPartyAppAnalyticsLinkService#regenerateshareablelinkid
         */
        regenerateShareableLinkId: (request: services.RegenerateShareableLinkIdRequest) => Promise<services.RegenerateShareableLinkIdResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/TravelAssetSuggestionService
     */
    get travelAssetSuggestions(): {
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/TravelAssetSuggestionService#suggesttravelassets
         */
        suggestTravelAssets: (request: services.SuggestTravelAssetsRequest) => Promise<services.SuggestTravelAssetsResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/UserDataService
     */
    get userData(): {
        /**
         * @link https://developers.google.com/google-ads/api/reference/rpc/v19/UserDataService#uploaduserdata
         */
        uploadUserData: (request: services.UploadUserDataRequest) => Promise<services.UploadUserDataResponse>;
    };
    /**
     * @link https://developers.google.com/google-ads/api/reference/rpc/v19/UserListCustomerTypeService
     */
    get userListCustomerTypes(): {
        /**
         * @description create resources of type resources.IUserListCustomerType
         * @returns services.MutateUserListCustomerTypesResponse
         */
        create: (userListCustomerTypes: (resources.IUserListCustomerType | resources.UserListCustomerType)[], options?: Partial<Pick<services.IMutateUserListCustomerTypesRequest, "validate_only" | "partial_failure">>) => Promise<services.MutateUserListCustomerTypesResponse>;
        /**
         * @description remove resources of type string
         * @returns services.MutateUserListCustomerTypesResponse
         */
        remove: (userListCustomerTypes: string[], options?: Partial<Pick<services.IMutateUserListCustomerTypesRequest, "validate_only" | "partial_failure">>) => Promise<services.MutateUserListCustomerTypesResponse>;
    };
}
